document.addEventListener("DOMContentLoaded",function(){var e=document.documentElement.lang||"fr",t={fr:{next:"Élément suivant",prev:"Élément précédent",pagination:"Aller à l'élément",first:"Premier élément",last:"Dernier élément"},en:{next:"Next slide",prev:"Previous slide",pagination:"Go to slide",first:"First slide",last:"Last slide"},de:{next:"Nächstes Element",prev:"Vorheriges Element",pagination:"Gehe zu Element",first:"Erstes Element",last:"Letztes Element"},nl:{next:"Volgende item",prev:"Vorig item",pagination:"Ga naar item",first:"Eerste item",last:"Laatste item"}};function i(i){return t[e]?t[e][i]:t.fr[i]}console.log("Current language:",e),$(".swiper").each(function(e){console.log("Initializing Swiper for element:");var t=parseInt($(this).attr("data-nb-results-by-batch"));isNaN(t)&&(t=1),new Swiper($(this)[0],{slidesPerView:1,slidesPerGroup:1,spaceBetween:10,pagination:{el:".swiper-pagination"},navigation:{nextEl:".swiper-button-next",prevEl:".swiper-button-prev"},a11y:{prevSlideMessage:i("prev"),nextSlideMessage:i("next"),paginationBulletMessage:i("pagination")+" {{index}}",firstSlideMessage:i("first"),lastSlideMessage:i("last")},breakpoints:{320:{slidesPerView:1,slidesPerGroup:1},576:{slidesPerView:t>1?2:1,slidesPerGroup:t>1?2:1},768:{slidesPerView:t>2?2:t,slidesPerGroup:t>2?2:t},992:{slidesPerView:t>2?3:t,slidesPerGroup:t>2?3:t},1200:{slidesPerView:t,slidesPerGroup:t}}})})});